/********************************************************************************/

/********************************************************************************/

/*  Comments added by Mark Wilbert (6-5-95):					*/

/*	This program extracts information from the standard digital orthophoto	*/

/* 	header and uses it to create the .hdr file required by ARC/INFO for	*/

/* 	the display of digital orthophoto images.				*/

/*										*/

/*	The files to be processed must have the ".bil" suffix.  The header	*/

/*	file created has the same root file name as the input file with a	*/

/*	".hdr" suffix added.							*/

/*										*/

/*	COMMAND:  bilhdr							*/

/*		  (Then respond to program prompts)				*/

/*										*/

/********************************************************************************/

/********************************************************************************/



#include <stdio.h>

/*

			Jere A. Swanson 1993



	data elements for standard digital orthophoto header records

*/

	typedef struct

	{

/*

	section 1

*/

	char quadname[39];

	char quadrant[3];

	char nations[2][3];

	char states[4][3];

	char st1cos[5][4];

	char st2cos[5][4];

	char st3cos[5][4];

	char st4cos[5][4];

	char filler[24];

	char producer[5];



	int datorder;

	int nlns[2];

	int bandtyps;

	int elevstor;

	int bestore;

	int vertdat;

	int prhordat;

	int sdhordat;



	double angle;



	int grid;

	int zone;

	int xyunits;



	double prqcorsw[2];

	double prqcornw[2];

	double prqcorne[2];

	double prqcorse[2];



	char compflag[2];

	char comploss[2];

	char compsftw[21];



	int compmeth;

	int compqual;

	int compsize;

	int lonlat[6];

/*

	section 2

*/

	double prxforma;

	double prxformb;

	double prxformc;

	double prxformd;

	double prxforme;

	double prxformf;

	double prxformx;

	double prxformy;

	double sdqcorsw[2];

	double sdqcornw[2];

	double sdqcorne[2];

	double sdqcorse[2];

/*

	section 3

*/

	double sdxforma;

	double sdxformb;

	double sdxformc;

	double sdxformd;

	double sdxforme;

	double sdxformf;

	double sdxformx;

	double sdxformy;



	int prqclssw[2];

	int prqclsnw[2];

	int prqclsne[2];

	int prqclsse[2];

	int sdqclssw[2];

	int sdqclsnw[2];

	int sdqclsne[2];

	int sdqclsse[2];



	double x1y1[2];

	double xnyn[2];

/*

	section 4

*/

	int elevunit;



	double minelev;

	double maxelev;

	double xgrndres;

	double ygrndres;

	double zgrndres;

	double xpixres;

	double ypixres;

	double zpixres;



	int maxconin;

	int maxconun;

	int minconin;

	int minconun;

	int susareac;



	double horizacc;

	double vertacc;



	int numhortp;

	int pixproal;



	char prodsyst[25];



	int proddate[3];



	char filmtype[25];

	char photoid[25];



	int moscode;



	char loffflag[3];



	int photodat[3];



	double focallen;



	int flyhgt;



	char scantype[25];



	double xyscres[2];

	double xyssres[2];



	int radres;



	double resmpres;

	} HEAD;







/*

			Jere A. Swanson 1993



	extracts entries from the standard digital orthophoto header and

	places the extracted values into the corresponding variables in the

	structure defined by headst.h

*/

	headin(s,fhi)

	HEAD *s;

	FILE *fhi;

	{

	char l1[400];

	char l2[400];

	char l3[400];

	char l4[400];

	char buf[200];

	int i,ns;

	int t;

/*

	read 400 bytes from record 1 

*/

	fread(l1,sizeof(char),400,fhi);

/*

	change D to E, first record

*/

	for(i=141;i<399;i++) if(l1[i]=='D') l1[i]='E';

/*

	get data from record 1

*/

	strncpy(s->quadname,&l1[0],38);

	s->quadname[38]=0;

	strncpy(s->quadrant,&l1[38],2);

	s->quadrant[2]=0;

	strncpy(&s->nations[0][0],&l1[40],2);

	s->nations[0][2]=0;

	strncpy(&s->nations[1][0],&l1[42],2);

	s->nations[1][2]=0;

	strncpy(&s->states[0][0],&l1[44],2);

	s->states[0][2]=0;

	strncpy(&s->states[1][0],&l1[46],2);

	s->states[1][2]=0;

	strncpy(&s->states[2][0],&l1[48],2);

	s->states[2][2]=0;

	strncpy(&s->states[3][0],&l1[50],2);

	s->states[3][2]=0;

	strncpy(&s->st1cos[0][0],&l1[52],3);

	s->st1cos[0][3]=0;

	strncpy(&s->st1cos[1][0],&l1[55],3);

	s->st1cos[1][3]=0;

	strncpy(&s->st1cos[2][0],&l1[58],3);

	s->st1cos[2][3]=0;

	strncpy(&s->st1cos[3][0],&l1[61],3);

	s->st1cos[3][3]=0;

	strncpy(&s->st1cos[4][0],&l1[64],3);

	s->st1cos[4][3]=0;

	strncpy(&s->st2cos[0][0],&l1[67],3);

	s->st2cos[0][3]=0;

	strncpy(&s->st2cos[1][0],&l1[70],3);

	s->st2cos[1][3]=0;

	strncpy(&s->st2cos[2][0],&l1[73],3);

	s->st2cos[2][3]=0;

	strncpy(&s->st2cos[3][0],&l1[76],3);

	s->st2cos[3][3]=0;

	strncpy(&s->st2cos[4][0],&l1[79],3);

	s->st2cos[4][3]=0;

	strncpy(&s->st3cos[0][0],&l1[82],3);

	s->st3cos[0][3]=0;

	strncpy(&s->st3cos[1][0],&l1[85],3);

	s->st3cos[1][3]=0;

	strncpy(&s->st3cos[2][0],&l1[88],3);

	s->st3cos[2][3]=0;

	strncpy(&s->st3cos[3][0],&l1[91],3);

	s->st3cos[3][3]=0;

	strncpy(&s->st3cos[4][0],&l1[94],3);

	s->st3cos[4][3]=0;

	strncpy(&s->st4cos[0][0],&l1[97],3);

	s->st4cos[0][3]=0;

	strncpy(&s->st4cos[1][0],&l1[100],3);

	s->st4cos[1][3]=0;

	strncpy(&s->st4cos[2][0],&l1[103],3);

	s->st4cos[2][3]=0;

	strncpy(&s->st4cos[3][0],&l1[106],3);

	s->st4cos[3][3]=0;

	strncpy(&s->st4cos[4][0],&l1[109],3);

	s->st4cos[4][3]=0;

	strncpy(s->filler,&l1[114],23);

	s->filler[23]=0;

	strncpy(s->producer,&l1[137],4);

	s->producer[4]=0;

	strncpy(buf,&l1[141],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->datorder);

	if(t!=1) s->datorder=0;

	strncpy(buf,&l1[144],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->nlns[0]);

	if(t!=1) s->nlns[0]=0;

	strncpy(buf,&l1[150],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->nlns[1]);

	if(t!=1) s->nlns[1]=0;

	ns=s->nlns[1];

	strncpy(buf,&l1[156],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->bandtyps);

	if(t!=1) s->bandtyps=0;

	strncpy(buf,&l1[159],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->elevstor);

	if(t!=1) s->elevstor=0;

	strncpy(buf,&l1[162],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->bestore);

	if(t!=1) s->bestore=0;

	strncpy(buf,&l1[165],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->vertdat);

	if(t!=1) s->vertdat=0;

	strncpy(buf,&l1[167],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->prhordat);

	if(t!=1) s->prhordat=0;

	strncpy(buf,&l1[169],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->sdhordat);

	if(t!=1) s->sdhordat=0;

	strncpy(buf,&l1[171],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->angle);

	if(t!=1) s->angle=0;

	strncpy(buf,&l1[195],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->grid);

	if(t!=1) s->grid=0;

	strncpy(buf,&l1[198],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->zone);

	if(t!=1) s->zone=0;

	strncpy(buf,&l1[204],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->xyunits);

	if(t!=1) s->xyunits=0;

	strncpy(buf,&l1[207],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcorsw[0]);

	if(t!=1) s->prqcorsw[0]=0;

	strncpy(buf,&l1[231],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcorsw[1]);

	if(t!=1) s->prqcorsw[1]=0;

	strncpy(buf,&l1[255],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcornw[0]);

	if(t!=1) s->prqcornw[0]=0;

	strncpy(buf,&l1[279],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcornw[1]);

	if(t!=1) s->prqcornw[1]=0;

	strncpy(buf,&l1[303],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcorne[0]);

	if(t!=1) s->prqcorne[0]=0;

	strncpy(buf,&l1[327],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcorne[1]);

	if(t!=1) s->prqcorne[1]=0;

	strncpy(buf,&l1[351],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcorse[0]);

	if(t!=1) s->prqcorse[0]=0;

	strncpy(buf,&l1[375],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prqcorse[1]);

	if(t!=1) s->prqcorse[1]=0;

/*

	set up and read remaining header records

*/

	fseek(fhi,ns,0);

	fread(l2,sizeof(char),400,fhi);

	fseek(fhi,2*ns,0);

	fread(l3,sizeof(char),400,fhi);

	fseek(fhi,3*ns,0);

	fread(l4,sizeof(char),400,fhi);

/*

	change D to E, remaining records

*/

	for(i=0;i<399;i++)   if(l2[i]=='D') l2[i]='E';

	for(i=0;i<399;i++)   if(l3[i]=='D') l3[i]='E';

	for(i=0;i<120;i++)   if(l4[i]=='D') l4[i]='E';

	for(i=145;i<154;i++) if(l4[i]=='D') l4[i]='E';

	for(i=203;i<233;i++) if(l4[i]=='D') l4[i]='E';

	for(i=258;i<399;i++) if(l4[i]=='D') l4[i]='E';

/*

	get data from record 2

*/

	strncpy(buf,&l2[0],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxforma);

	if(t!=1) s->prxforma=0;

	strncpy(buf,&l2[24],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxformb);

	if(t!=1) s->prxformb=0;

	strncpy(buf,&l2[48],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxformc);

	if(t!=1) s->prxformc=0;

	strncpy(buf,&l2[72],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxformd);

	if(t!=1) s->prxformd=0;

	strncpy(buf,&l2[96],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxforme);

	if(t!=1) s->prxforme=0;

	strncpy(buf,&l2[120],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxformf);

	if(t!=1) s->prxformf=0;

	strncpy(buf,&l2[144],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxformx);

	if(t!=1) s->prxformx=0;

	strncpy(buf,&l2[168],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->prxformy);

	if(t!=1) s->prxformy=0;

	strncpy(buf,&l2[192],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcorsw[0]);

	if(t!=1) s->sdqcorsw[0]=0;

	strncpy(buf,&l2[216],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcorsw[1]);

	if(t!=1) s->sdqcorsw[1]=0;

	strncpy(buf,&l2[240],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcornw[0]);

	if(t!=1) s->sdqcornw[0]=0;

	strncpy(buf,&l2[264],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcornw[1]);

	if(t!=1) s->sdqcornw[1]=0;

	strncpy(buf,&l2[288],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcorne[0]);

	if(t!=1) s->sdqcorne[0]=0;

	strncpy(buf,&l2[312],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcorne[1]);

	if(t!=1) s->sdqcorne[1]=0;

	strncpy(buf,&l2[336],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcorse[0]);

	if(t!=1) s->sdqcorse[0]=0;

	strncpy(buf,&l2[360],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdqcorse[1]);

	if(t!=1) s->sdqcorse[1]=0;

/*

	get data from record 3

*/

	strncpy(buf,&l3[0],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxforma);

	if(t!=1) s->sdxforma=0;

	strncpy(buf,&l3[24],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxformb);

	if(t!=1) s->sdxformb=0;

	strncpy(buf,&l3[48],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxformc);

	if(t!=1) s->sdxformc=0;

	strncpy(buf,&l3[72],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxformd);

	if(t!=1) s->sdxformd=0;

	strncpy(buf,&l3[96],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxforme);

	if(t!=1) s->sdxforme=0;

	strncpy(buf,&l3[120],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxformf);

	if(t!=1) s->sdxformf=0;

	strncpy(buf,&l3[144],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxformx);

	if(t!=1) s->sdxformx=0;

	strncpy(buf,&l3[168],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->sdxformy);

	if(t!=1) s->sdxformy=0;

	strncpy(buf,&l3[192],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclssw[0]);

	if(t!=1) s->prqclssw[0]=0;

	strncpy(buf,&l3[198],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclssw[1]);

	if(t!=1) s->prqclssw[1]=0;

	strncpy(buf,&l3[204],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclsnw[0]);

	if(t!=1) s->prqclsnw[0]=0;

	strncpy(buf,&l3[210],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclsnw[1]);

	if(t!=1) s->prqclsnw[1]=0;

	strncpy(buf,&l3[216],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclsne[0]);

	if(t!=1) s->prqclsne[0]=0;

	strncpy(buf,&l3[222],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclsne[1]);

	if(t!=1) s->prqclsne[1]=0;

	strncpy(buf,&l3[228],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclsse[0]);

	if(t!=1) s->prqclsse[0]=0;

	strncpy(buf,&l3[234],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->prqclsse[1]);

	if(t!=1) s->prqclsse[1]=0;

	strncpy(buf,&l3[240],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclssw[0]);

	if(t!=1) s->sdqclssw[0]=0;

	strncpy(buf,&l3[246],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclssw[1]);

	if(t!=1) s->sdqclssw[1]=0;

	strncpy(buf,&l3[252],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclsnw[0]);

	if(t!=1) s->sdqclsnw[0]=0;

	strncpy(buf,&l3[258],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclsnw[1]);

	if(t!=1) s->sdqclsnw[1]=0;

	strncpy(buf,&l3[264],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclsne[0]);

	if(t!=1) s->sdqclsne[0]=0;

	strncpy(buf,&l3[270],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclsne[1]);

	if(t!=1) s->sdqclsne[1]=0;

	strncpy(buf,&l3[276],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclsse[0]);

	if(t!=1) s->sdqclsse[0]=0;

	strncpy(buf,&l3[282],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->sdqclsse[1]);

	if(t!=1) s->sdqclsse[1]=0;

	strncpy(buf,&l3[288],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->x1y1[0]);

	if(t!=1) s->x1y1[0]=0;

	strncpy(buf,&l3[312],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->x1y1[1]);

	if(t!=1) s->x1y1[1]=0;

	strncpy(buf,&l3[336],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->xnyn[0]);

	if(t!=1) s->xnyn[0]=0;

	strncpy(buf,&l3[360],24);

	buf[24]=0;

	t=sscanf(buf,"%lf",&s->xnyn[1]);

	if(t!=1) s->xnyn[1]=0;

/*

	get data from record 4

*/

	strncpy(buf,&l4[0],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->elevunit);

	if(t!=1) s->elevunit=0;

	strncpy(buf,&l4[3],10);

	buf[10]=0;

	t=sscanf(buf,"%lf",&s->minelev);

	if(t!=1) s->minelev=0;

	strncpy(buf,&l4[13],10);

	buf[10]=0;

	t=sscanf(buf,"%lf",&s->maxelev);

	if(t!=1) s->maxelev=0;

	strncpy(buf,&l4[23],12);

	buf[12]=0;

	t=sscanf(buf,"%lf",&s->xgrndres);

	if(t!=1) s->xgrndres=0;

	strncpy(buf,&l4[35],12);

	buf[12]=0;

	t=sscanf(buf,"%lf",&s->ygrndres);

	if(t!=1) s->ygrndres=0;

	strncpy(buf,&l4[47],12);

	buf[12]=0;

	t=sscanf(buf,"%lf",&s->zgrndres);

	if(t!=1) s->zgrndres=0;

	strncpy(buf,&l4[59],12);

	buf[12]=0;

	t=sscanf(buf,"%lf",&s->xpixres);

	if(t!=1) s->xpixres=0;

	strncpy(buf,&l4[71],12);

	buf[12]=0;

	t=sscanf(buf,"%lf",&s->ypixres);

	if(t!=1) s->ypixres=0;

	strncpy(buf,&l4[83],12);

	buf[12]=0;

	t=sscanf(buf,"%lf",&s->zpixres);

	if(t!=1) s->zpixres=0;

	strncpy(buf,&l4[95],5);

	buf[5]=0;

	t=sscanf(buf,"%d",&s->maxconin);

	if(t!=1) s->maxconin=0;

	strncpy(buf,&l4[100],1);

	buf[1]=0;

	t=sscanf(buf,"%d",&s->maxconun);

	if(t!=1) s->maxconun=0;

	strncpy(buf,&l4[101],5);

	buf[5]=0;

	t=sscanf(buf,"%d",&s->minconin);

	if(t!=1) s->minconin=0;

	strncpy(buf,&l4[106],1);

	buf[1]=0;

	t=sscanf(buf,"%d",&s->minconun);

	if(t!=1) s->minconun=0;

	strncpy(buf,&l4[107],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->susareac);

	if(t!=1) s->susareac=0;

	strncpy(buf,&l4[109],6);

	buf[6]=0;

	t=sscanf(buf,"%lf",&s->horizacc);

	if(t!=1) s->horizacc=0;

	strncpy(buf,&l4[115],6);

	buf[6]=0;

	t=sscanf(buf,"%lf",&s->vertacc);

	if(t!=1) s->vertacc=0;

	strncpy(buf,&l4[121],4);

	buf[4]=0;

	t=sscanf(buf,"%d",&s->numhortp);

	if(t!=1) s->numhortp=0;

	strncpy(buf,&l4[125],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->pixproal);

	if(t!=1) s->pixproal=0;

	strncpy(s->prodsyst,&l4[127],24);

	s->prodsyst[24]=0;

	strncpy(buf,&l4[151],6);

	buf[6]=0;

	t=sscanf(buf,"%d",&s->proddate[0]);

	if(t!=1) s->proddate[0]=0;

	strncpy(buf,&l4[157],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->proddate[1]);

	if(t!=1) s->proddate[1]=0;

	strncpy(buf,&l4[159],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->proddate[2]);

	if(t!=1) s->proddate[2]=0;

	strncpy(s->filmtype,&l4[161],24);

	s->filmtype[24]=0;

	strncpy(s->photoid,&l4[185],24);

	s->photoid[24]=0;

	strncpy(buf,&l4[209],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->moscode);

	if(t!=1) s->moscode=0;

	strncpy(s->loffflag,&l4[212],2);

	s->loffflag[2]=0;

	strncpy(buf,&l4[214],4);

	buf[4]=0;

	t=sscanf(buf,"%d",&s->photodat[0]);

	if(t!=1) s->photodat[0]=0;

	strncpy(buf,&l4[218],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->photodat[1]);

	if(t!=1) s->photodat[1]=0;

	strncpy(buf,&l4[220],2);

	buf[2]=0;

	t=sscanf(buf,"%d",&s->photodat[2]);

	if(t!=1) s->photodat[2]=0;

	strncpy(buf,&l4[222],8);

	buf[8]=0;

	t=sscanf(buf,"%lf",&s->focallen);

	if(t!=1) s->focallen=0;

	strncpy(buf,&l4[230],10);

	buf[10]=0;

	t=sscanf(buf,"%d",&s->flyhgt);

	if(t!=1) s->flyhgt=0;

	strncpy(s->scantype,&l4[240],24);

	s->scantype[24]=0;

	strncpy(buf,&l4[264],6);

	buf[6]=0;

	t=sscanf(buf,"%lf",&s->xyscres[0]);

	if(t!=1) s->xyscres[0]=0;

	strncpy(buf,&l4[270],6);

	buf[6]=0;

	t=sscanf(buf,"%lf",&s->xyscres[1]);

	if(t!=1) s->xyscres[1]=0;

	strncpy(buf,&l4[276],6);

	buf[6]=0;

	t=sscanf(buf,"%lf",&s->xyssres[0]);

	if(t!=1) s->xyssres[0]=0;

	strncpy(buf,&l4[282],6);

	buf[6]=0;

	t=sscanf(buf,"%lf",&s->xyssres[1]);

	if(t!=1) s->xyssres[1]=0;

	strncpy(buf,&l4[288],3);

	buf[3]=0;

	t=sscanf(buf,"%d",&s->radres);

	if(t!=1) s->radres=0;

	strncpy(buf,&l4[291],6);

	buf[6]=0;

	t=sscanf(buf,"%lf",&s->resmpres);

	if(t!=1) s->resmpres=0;

	strncpy(s->compflag,&l4[298],1);

	s->compflag[1]=0;

	strncpy(buf,&l4[300],9);

	buf[9]=0;

	t=sscanf(buf,"%d",&s->compsize);

	if(t!=1) s->compsize=0;

	strncpy(s->compsftw,&l4[310],20);

	s->compsftw[20]=0;

	strncpy(s->comploss,&l4[331],1);

	s->comploss[1]=0;

	strncpy(buf,&l4[333],4);

	buf[4]=0;

	t=sscanf(buf,"%d",&s->compqual);

	if(t!=1) s->compqual=0;

	}







	mkarchdr(doq,dat,xsh,ysh,f)

	char doq[];

	int dat,*f;

	double xsh,ysh;

	{

	FILE *ifp,*ofp;

	char ifn[100],ofn[100];

	int nl,ns;

	double x,y,xr,yr;

	HEAD h;



	*f=1;

	strcpy(ifn,doq);

	strcat(ifn,".bil");

	ifp=fopen(ifn,"r");

	if(ifp==0) return;

	strcpy(ofn,doq);

	strcat(ofn,".hdr");

	ofp=fopen(ofn,"w");



	headin(&h,ifp);

	if((dat==27)&&(h.prhordat==1)){x=h.x1y1[0]; y=h.x1y1[1];}

	if((dat==27)&&(h.prhordat==4)){x=h.xnyn[0]; y=h.xnyn[1];}

	if((dat==83)&&(h.prhordat==1)){x=h.xnyn[0]; y=h.xnyn[1];}

	if((dat==83)&&(h.prhordat==4)){x=h.x1y1[0]; y=h.x1y1[1];}

	nl=h.nlns[0];

	ns=h.nlns[1];

	xr=h.xpixres;

	yr=h.ypixres;

	fprintf(ofp,"nrows %d\n",nl);

	fprintf(ofp,"ncols %d\n",ns);

	fprintf(ofp,"ulxmap %10.2lf\n",x-xsh);

	fprintf(ofp,"ulymap %10.2lf\n",y-ysh);

	fprintf(ofp,"xdim %10.2lf\n",xr);

	fprintf(ofp,"ydim %10.2lf\n",yr);

	fprintf(ofp,"skipbytes %d\n",4*ns);

	*f=0;

	}





	main()

	{

	char doq[100],s;

	int dat,f;

	double xsh,ysh;

	do

		{

		printf(" Please enter image file root name\n > ");

		scanf("%s",doq);

		printf(" Please enter datum (27 or 83)\n > ");

		scanf("%d",&dat);

		printf(" Please enter x and y shifts\n > ");

		scanf("%lf%lf",&xsh,&ysh);

		mkarchdr(doq,dat,xsh,ysh,&f);

		if(f!=0)

			{

			printf(" Cannot open input file\n");

			printf(" Enter 'q' to quit\n");

			scanf("%c",s);

			if(s=='q') exit(0);

			}

		} while(f!=0);

	}

